<?php
/*
 * Discussion Board Pro Skins class
 * @since 1.4.0
*/

// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( ! class_exists( 'CT_DB_Pro_Skins' ) ) {

	class CT_DB_Pro_Skins extends CT_DB_Skins {

		public function __construct() {

		}

		/*
		 * Initialize the class and start calling our hooks and filters
		 * @since 1.4.0
		 */
		public function init() {

			add_action( 'wp_head', array( $this, 'add_styles' ) );

			add_filter( 'ctdb_topic_meta_data_fields', array( $this, 'extend_available_fields' ) );

			// http://wordpress.stackexchange.com/a/36110
			global $CT_DB_Skins;
			remove_filter( 'ctdb_meta_fields', array( $CT_DB_Skins, 'insert_meta_fields' ) );
			add_filter( 'ctdb_meta_fields', array( $this, 'insert_pro_meta_fields' ), 10, 3 );

		}

		/*
		 * Add Customizer styles into the header
		 * @since 1.6.4
		 */
		public function add_styles() {
			$settings = ctdb_pro_customizer_settings();
			$styles = array();

			$options = get_option( 'ctdb_design_settings' );
			// Iterate through design settings that can be updated in Customizer
			if( ! empty( $settings ) ) {
				foreach( $settings as $setting ) {
					// If the setting has a value and it has a style declaration
					if( isset( $options[$setting['id']] ) && isset( $setting['declaration'] ) ) {
						// Create a new rule for the element
						$newrule = $setting['element'] . ' {';
							$newrule .= $setting['declaration'] . ':' . $options[$setting['id']];
						$newrule .= '}';
						$styles[] = $newrule;
					}
				}
			}

			if( ! empty( $styles ) ) {
				echo '<style type="text/css" id="ctdb-custom-styles">';
				echo join( ' ', $styles );
				echo '</style>';
			}
		}

		/*
		 * Add more topic meta fields
		 * @since 1.2.0
		*/
		public function extend_available_fields( $fields ) {
			$fields['freshness'] = __( 'Freshness', 'discussion-board-pro' );
			$fields['followers'] = __( 'Followers', 'discussion-board-pro' );
			$fields['status'] = __( 'Status', 'discussion-board-pro' );
			return $fields;
		}

		/*
		 * Return the topic fields
		 * @since 1.7.0
		 */
		public function insert_pro_meta_fields( $output, $fields, $field_titles ) {

			global $post;

			$show_icons = ctdb_use_icons();

			foreach( $fields as $key=>$value ) {

				if( isset( $field_titles[$key] ) ) {

					// We only output content if it's supposed to be there, i.e. the key appears in the $field_titles array
					// $field_titles is defined in functions-skins.php

					// Number of replies
					if( $key == 'replies' ) {

						$output .= '<div class="ctdb-info-title ctdb-info-cell">';
							if( $show_icons ) $output .= '<span class="dashicons dashicons-format-chat"></span>';
							$output .= esc_html( $field_titles[$key] );
						$output .= '</div><!-- .ctdb-info-title -->';
						$output .= '<div class="ctdb-info-meta-wrap ctdb-info-cell">';
							$output .= '<div class="ctdb-info-meta">';
								$output .= get_comments_number();
							$output .= '</div><!-- .ctdb-info-meta -->';
						$output .= '</div><!-- .ctdb-info-meta-wrap -->';

					} else if( $key == 'voices' ) {

						$output .= '<div class="ctdb-info-title ctdb-info-cell">';
							if( $show_icons ) $output .= '<span class="dashicons dashicons-groups"></span>';
							$output .= esc_html( $field_titles[$key] );
						$output .= '</div><!-- .ctdb-info-title -->';
						$output .= '<div class="ctdb-info-meta-wrap ctdb-info-cell">';
							$output .= '<div class="ctdb-info-meta">';
								$comments = get_comments( $post );
								$output .= $this->count_voices( $comments );
							$output .= '</div><!-- .ctdb-info-meta -->';
						$output .= '</div><!-- .ctdb-info-meta-wrap -->';

					} else if( $key == 'freshness' ) {

						$output .= '<div class="ctdb-info-title ctdb-info-cell">';
							if( $show_icons ) $output .= '<span class="dashicons dashicons-clock"></span>';
							$output .= esc_html( $field_titles[$key] );
						$output .= '</div><!-- .ctdb-info-title -->';
						$output .= '<div class="ctdb-info-meta-wrap ctdb-info-cell">';
							$output .= '<div class="ctdb-info-meta">';
								$date = get_post_meta( $post->ID, 'ctdb_most_recent_activity', true );
								if( ! empty( $date ) ) {
									$format = get_option( 'date_format' );
									$output .= '<time class="timeago" datetime="' . date( 'c', $date ) . '">' . date( $format, $date ) . '</time>';
								}
							$output .= '</div><!-- .ctdb-info-meta -->';
						$output .= '</div><!-- .ctdb-info-meta-wrap -->';

					} else if( $key == 'followers' ) {

						$output .= '<div class="ctdb-info-title ctdb-info-cell">';
							if( $show_icons ) $output .= '<span class="dashicons dashicons-visibility"></span>';
							$output .= esc_html( $field_titles[$key] );
						$output .= '</div><!-- .ctdb-info-title -->';
						$output .= '<div class="ctdb-info-meta-wrap ctdb-info-cell">';
							$output .= '<div class="ctdb-info-meta">';
								$followers = get_post_meta( $post->ID, 'ctdb_follow_this_topic', true );
								$followers = apply_filters( 'ctdb_follow_this_topic', $followers, $post->ID );
								if( ! empty( $followers ) ) {
									$followers_count = count( $followers );
								} else {
									// Array is empty
									$followers_count = 0;
								}
								$followers_count = '<p class="ctdb-follower-count"><span>' . $followers_count . '</span></p>';
								/*
								 * @hooked CT_DB_Pro_Followers::add_followers_box
								 */
								$followers_count = apply_filters( 'ctdb_followers_count', $followers_count );
								$output .= $followers_count;
							$output .= '</div><!-- .ctdb-info-meta -->';
						$output .= '</div><!-- .ctdb-info-meta-wrap -->';

					} else if( $key == 'status' ) {

						// Check for status metafield
						$status = ctdb_status();
						$output .= '<div class="ctdb-info-title ctdb-info-cell">';
							if( $show_icons ) $output .= '<span class="dashicons dashicons-post-status"></span>';
							$output .= esc_html( $field_titles[$key] );
						$output .= '</div><!-- .ctdb-info-title -->';
						$output .= '<div class="ctdb-info-meta-wrap ctdb-info-cell ctdb-status-' . esc_attr( strtolower( $status ) ) . '">';
							$output .= '<div class="ctdb-info-meta">';
								// Determine whether to output status as string or select
								$status_output = ctdb_status_output();
								$output .= $status_output;
							$output .= '</div><!-- .ctdb-info-meta -->';
						$output .= '</div><!-- .ctdb-info-meta-wrap -->';

					}

				}

			}

			/*
			 * @hooked CT_DB_Pro_Categories::display_categories_table_layout	Add category and tag fields
			 */
			$output = apply_filters( 'ctdb_meta_fields_end', $output );

			return $output;

		}

	}

	$CT_DB_Pro_Skins = new CT_DB_Pro_Skins();
	$CT_DB_Pro_Skins->init();

}
